<?php
namespace plugin\wz_chat\api;

use Workerman\Connection\TcpConnection;
use Workerman\Protocols\Http\Request;
use Workerman\Protocols\Http\Response;
use Workerman\Timer;
use Workerman\Worker;

define('HOOK_OFFLINE', config('plugin.wz_chat.process.wz_chat.webHook.offline'));
define('HOOK_ONLINE', config('plugin.wz_chat.process.wz_chat.webHook.online'));


class Pusher
{
    protected static $connections = [];
     
    protected $httpWorker = null;
    
    
    public function onWorkerStart()
    {
        $this->httpWorker = new Worker('http://0.0.0.0:8848');
        $this->httpWorker->onMessage = [$this, 'onHttpRequest'];
        $this->httpWorker->listen();
        Timer::add(20, [$this,'checkActive']);
        
    }
    public function checkActive(){
        foreach (self::$connections as $user_id=>$connections){
            foreach ($connections as $conn){
                if($conn->active <= 0){
                    $conn->close();
                    continue;
                }
                $conn->active --;
            }
        }
    }
    public function onMessage(TcpConnection $connection, $data)
    {
        $data = json_decode($data,true);
        $type = $data['type'];
        if($type == 'ping'){
            $connection->active = 2;
            return $connection->send(json_encode(['type'=>'pong','data'=>[]]));
        }
        
    }
    
    
    public function onWebSocketConnect(TcpConnection $connection, $request)
    {
        
        /**
        $origin = $request->header('origin');
        $allowedOrigins = [
            'http://127.0.0.1:8787',
            'http://localhost:8787',
        ];
        //var_dump($origin);
        if (!in_array($origin, $allowedOrigins)) {
            $connection->close('Origin not allowed');
            return;
        }
        */
        
        if (!preg_match('/GET \/uid\/(\d+)/', (string)$request, $matches)) {
            $connection->close('');
        }
        $user_id = $matches[1];
        $connection->user_id = $user_id; 
        $connection->active = 2;
        
        self::$connections[$user_id][$connection->id] = $connection;
        
        Timer::add(0.1, function()use($user_id){
            if(Pusher::$connections[$user_id]){
                wz_curl(HOOK_ONLINE, ['user_id'=>$user_id]);
            } 
        },[],false);
    }
    
    
    public function onClose(TcpConnection $connection)
    {
        if (!isset($connection->user_id)) {
            return;
        }
        $user_id = $connection->user_id;
        if (!isset(self::$connections[$user_id])) {
            return;
        }
        unset(self::$connections[$user_id][$connection->id]);
        if (empty(self::$connections[$user_id])) {
            unset(self::$connections[$user_id]);          
            Timer::add(4,function()use($user_id){
                if (!empty(Pusher::$connections[$user_id])) {
                    return;
                }
                wz_curl(HOOK_OFFLINE, ['user_id'=>$user_id]);
            },[],false);
        }
    }
    
    
    public function onHttpRequest(TcpConnection $connection, Request $request)
    {
        if ($request->method() !== 'POST') {
            return $connection->send(new Response(405, [], 'Method Not Allowed'));
        }
        $target = $request->post('target'); 
        $message = $request->post('message');
        if (!$target || !$message) {
            return $connection->send(new Response(400, [], 'Bad Request'));
        }
        $connection->send(new Response(200, [], json_encode(['code' => 0 ])));
        
        Timer::add(0.1, [$this,'push'],[$target, $message],false);
    }
    
    
    function push($target, array $message)
    {
        $message = json_encode($message);
        if (is_numeric($target) || is_string($target)) {
            if (isset(self::$connections[$target])) {
                foreach (self::$connections[$target] as $conn) {
                    $conn->send($message);
                }
            }
        } elseif (is_array($target)) {
            foreach ($target as $user_id){
                if(isset(self::$connections[$user_id])){
                    foreach (self::$connections[$user_id] as $conn){
                        $conn->send($message);
                    }
                }
            }
        } elseif ($target === 'ALL') {
            $i = 0;
            foreach (self::$connections as $user_id => $connections){
                if(++$i>5000){
                    return;
                }
                foreach ($connections as $conn){
                    $conn->send($message);
                }
            }
        }
    }
}