<?php

/**
 * Here is your custom functions.
 */
/**
 * 下面的一堆函数 
 * 有的 把用户、群、好友、关系 记录一下
 * 有的 查询 、推送、
 * 
 */


/**
 * 用户上线
 * @param int $uid 用户ID
 * @param array $gids 群组ID数组
 * @param array $fids 好友ID数组
 */
function wz_user_online($uid, array $gids = [], array $fids = []) {
    // 设置用户在线状态（记录最后活跃时间戳）
    \support\Redis::set("wz-user:online:{$uid}", time());
    // 处理群组关系
    if (!empty($gids)) {
        \support\Redis::pipeline(function($pipe) use ($uid, $gids) {
            foreach ($gids as $gid) {
                // 将用户添加到群组在线集合
                $pipe->sAdd("wz-group:online:{$gid}", $uid);
            }
            // 记录用户群组关系
            $pipe->sAdd("wz-user:groups:{$uid}", ...$gids);
        });
    }
    // 处理好友关系
    if (!empty($fids)) {
        \support\Redis::pipeline(function($pipe) use ($uid, $fids) {
            foreach ($fids as $fid) {
                // 将用户添加到每个好友的"好友在线"集合
                $pipe->sAdd("wz-friend:online:{$fid}", $uid);
            }
            // 记录用户好友关系
            $pipe->sAdd("wz-user:friends:{$uid}", ...$fids);
        }); 
    }
}


/**
 *
 * @param unknown $uid
 * @param unknown $fid
 * @return boolean
 */
function wz_user_is_friend($uid, $fid) {
    return \support\Redis::sIsMember("wz-user:friends:{$uid}", $fid);
}

function wz_user_online_notify($uid){    
    $fids = wz_get_friends($uid);
    if (!empty($fids)) {
        wz_push($fids, [
            'type' => 'friend-online',
            'data' => [
                'user_id' => $uid,
                'online' => true,
                'timestamp' => time()
            ]
        ]);
    }
}
function wz_user_offline_notify($uid){
    $fids = wz_get_friends($uid);
    if(!empty($fids)){
        wz_push($fids, [
            'type' => 'friend-online',
            'data' => [
                'user_id' => $uid,
                'online' => false,
                'timestamp' => time()
            ]
        ]);
    }
    wz_user_offline($uid);
}

/**
 * 添加好友 双向
 * @param unknown $uid
 * @param unknown $fid
 * @param string $online
 */
function wz_add_friend($uid, $fid, $online = false) {
    // Add the friend relationship for both users
    \support\Redis::pipeline(function($pipe) use ($uid, $fid,$online) {
        // Add fid to uid's friend list
        $pipe->sAdd("wz-user:friends:{$uid}", $fid);
        // Add uid to fid's friend list (reciprocal relationship)
        $online && $pipe->sAdd("wz-user:friends:{$fid}", $uid);
    });      
    // If the friend is online, add to online sets
    if ($online) {
        \support\Redis::pipeline(function($pipe) use ($uid, $fid) {
            // Add uid to fid's online friends
            $pipe->sAdd("wz-friend:online:{$fid}", $uid);
            // Add fid to uid's online friends
            $pipe->sAdd("wz-friend:online:{$uid}", $fid);
        });
    }
}

/**
 * 用户离线
 * @param int $uid 用户ID
 */
function wz_user_offline($uid) {
    // 获取用户所有关联群组
    $gids = \support\Redis::sMembers("wz-user:groups:{$uid}");
    // 获取用户所有关联好友
    $fids = \support\Redis::sMembers("wz-user:friends:{$uid}");
    
    if (!empty($gids) || !empty($fids)) {
        \support\Redis::pipeline(function($pipe) use ($uid, $gids, $fids) {
            // 处理群组关系
            foreach ($gids as $gid) {
                // 从群组在线集合移除用户
                $pipe->sRem("wz-group:online:{$gid}", $uid);
            }
            // 删除用户群组关系记录
            $pipe->del("wz-user:groups:{$uid}");
            
            // 处理好友关系
            foreach ($fids as $fid) {
                // 从好友的"好友在线"集合中移除用户
                $pipe->sRem("wz-friend:online:{$fid}", $uid);
            }
            // 删除用户好友关系记录
            $pipe->del("wz-user:friends:{$uid}");
        });
    }
    // 删除在线状态
    \support\Redis::del("wz-user:online:{$uid}");
}
/**
 * 获取用户好友ID列表
 * @param int $uid 用户ID
 * @return array 在线好友ID数组
 */
function wz_get_friends($uid,$excludeFid = null) {
    // 1. 获取用户所有好友ID
    $fids = \support\Redis::sMembers("wz-user:friends:{$uid}")??[];
    
    if (empty($fids)) {
        return [];
    }
    if ($excludeFid!== null) {
        if (is_array($excludeFid)) {
            $fids= array_diff($fids, $excludeFid);
        } else {
            $fids= array_diff($fids, [$excludeFid]);
        }
    }
    return array_values($fids); // 重新索引数组
}


/**
 * 获取用户在线好友ID列表
 * @param int $uid 用户ID
 * @return array 在线好友ID数组
 */
function wz_get_online_friends($uid) {
    // 直接读取该用户的"谁把我标记为在线好友"的集合 
    return \support\Redis::sMembers("wz-friend:online:{$uid}") ?: []; 
}

function wz_group_add_user($gid, $uids) {
    // 将单个用户ID转换为数组形式统一处理
    $uids = is_array($uids) ? $uids : [$uids];
    
    \support\Redis::pipeline(function($pipe) use ($uids, $gid) {
        foreach ($uids as $uid) {
            // 记录用户群组关系
            $pipe->sAdd("wz-user:groups:{$uid}", $gid);
            
            // 如果用户在线，添加到群组在线列表
            if ($pipe->exists("wz-user:online:{$uid}")) {
                $pipe->sAdd("wz-group:online:{$gid}", $uid);
            }
        }
    });
}
/**
 * 检查用户是否在群组中
 * @param int $userId 用户ID
 * @param int $groupId 群组ID
 * @return bool
 */
function wz_is_group_member($uid, $gid) {
    return \support\Redis::sIsMember("wz-user:groups:{$uid}", $gid);
}
/**
 * 用户离开/被移出群组
 * @param int $uid 用户ID
 * @param int $gid 群组ID
 */
function wz_group_remove_user($uid, $gid) {
    \support\Redis::pipeline(function($pipe) use ($uid, $gid) {
        // 从用户群组关系移除
        $pipe->sRem("wz-user:groups:{$uid}", $gid);
        
        // 从群组在线列表移除
        $pipe->sRem("wz-group:online:{$gid}", $uid);
    });
}

/**
 * 获取群组在线用户数
 * @param int $gid 群组ID
 * @return int
 */
function wz_get_group_online_count($gid) {
    return \support\Redis::sCard("wz-group:online:{$gid}");
}

/**
 * 获取群组所有在线用户ID（可排除特定用户）
 * @param int $gid 群组ID
 * @param mixed $excludeUid 要排除的用户ID（可选，可以是单个ID或数组）
 * @return array
 */
function wz_get_group_online_users($gid, $excludeUid = null) {
    $users = \support\Redis::sMembers("wz-group:online:{$gid}")??[];
    
    if ($excludeUid !== null) {
        if (is_array($excludeUid)) {
            $users = array_diff($users, $excludeUid);
        } else {
            $users = array_diff($users, [$excludeUid]);
        }
    }
    
    return array_values($users); // 重新索引数组
}

/**
 * 检查用户是否在线
 * @param int $uid 用户ID
 * @return bool
 */
function wz_user_is_online($uid) {
    return \support\Redis::exists("wz-user:online:{$uid}");
}

/**
 * 获取用户所在的所有群组ID
 * @param int $uid 用户ID
 * @return array
 */
function wz_get_user_groups($uid,$excludeGid=null) {
    $gids = \support\Redis::sMembers("wz-user:groups:{$uid}")?:[];
    if(empty($gids)){
        return [];
    }
    if ($excludeGid!== null) {
        if (is_array($excludeGid)) {
            $gids= array_diff($gids, $excludeGid);
        } else {
            $gids= array_diff($gids, [$excludeGid]);
        }
    }
    return array_values($gids);
}



function wz_curl(string $url,array $postData){
    $ch = curl_init();
    curl_setopt_array($ch, [
        CURLOPT_URL => $url,
        CURLOPT_POST => true,
        CURLOPT_POSTFIELDS => json_encode($postData),
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_TIMEOUT => 5,
        CURLOPT_HTTPHEADER => [
            'Content-Type: application/json',
            'User-Agent: MyPushClient/1.0'
        ]
    ]);
    $response = curl_exec($ch);
    curl_close($ch);
    try {
        $result = json_decode($response, true);
        return $result;
    } catch (\Exception $e) {
        return false;
    }
}


/**
 * 推送
 * @param string $target
 * @param array $message
 * @throws Exception
 * @return mixed
 */
function wz_push($target, array $message) {
    $url = 'http://127.0.0.1:8848';
    $postData = [
        'target' => $target,
        'message' => $message // 直接传递数组
    ];
    return wz_curl($url, $postData);
}
/**
 * @abstract
 * 传入 文件名
 * 
 * 解析成 vue js 组件
 * 文件内容示例：
 * <template>
 *  <div>
 *      ...
 *  </div>
 * </template>
 * <script>
 *  //const { mapState,mapGetters } = Vuex;
 *  //import Test1 from '解析vue的接口地址?参数名';
 *  export default {
 *     name:'Test',
 *     computed: {   
 *       //...mapState('count')
 *     },
 *     data(){
 *        return {} 
 *     },
 *     props:{
 *     
 *     },
 *     methods:{
 *       
 *     }
 *  }
 * </script>
 * <style>
 *    ...
 * </style>
 * 
 * 
 * 
 * @param unknown $file
 * @return string
 */
function parse_vue($file) {
    $vueContent = file_get_contents($file);
    $parsed = [
        'template' => '',
        'script' => 'export default {}',
        'style' => ''
    ];
    if (preg_match('/<\s*template[^>]*>([\s\S]*)<\/\s*template\s*>/', $vueContent, $matches)) {
        $parsed['template'] = trim($matches[1]);
    }
    if (preg_match('/<\s*style[^>]*>([\s\S]*)<\/\s*style\s*>/', $vueContent, $matches)) {
        $parsed['style'] = trim($matches[1]);
    }
    if (preg_match('/<\s*script[^>]*>([\s\S]*)<\/\s*script\s*>/', $vueContent, $matches)) {
        if (strpos(trim($matches[1]), 'export default') !== false) {
            $parsed['script'] = trim($matches[1]);
        } else {
            $parsed['script'] = 'export default ' . trim($matches[1]);
        }
    }   
    // 生成scoped ID
    $scopedId = 'scoped-' . bin2hex(random_bytes(4));
    $scopedStyles = '';
    
    if (!empty($parsed['style'])) {
        $scopedStyles = preg_replace_callback(
            '/(([^{]+){([^}]*)})/xs',
            function($matches) use ($scopedId) {
                //var_dump($matches);
                $selectors = array_filter(array_map('trim', explode(',', $matches[2])));
                $processed = array_map(function($sel) use ($scopedId) {
                    // 跳过 :global() 规则
                    if (preg_match('/:global\((.+)\)/', $sel, $globalMatches)) {
                        return trim($globalMatches[1]);
                    }
                    // 跳过伪类/伪元素和 html/:root
                    $excluded = ['html', ':root'];
                    $trimmed = trim($sel);
                    if (in_array($trimmed, $excluded, true) || strpos($trimmed, ':') !== false) {
                        return $sel;
                    }
                    // 其他选择器添加作用域
                    return "[data-{$scopedId}]{$sel}, [data-{$scopedId}] {$sel}";
                }, $selectors);
                    
                    return implode(',', $processed) . '{' . $matches[3] . '}';
            },
            $parsed['style']
            );
        
    } 
    
    $scopedTemplate = preg_replace(
        '/^(\s*<[\w-]+)/m',
        "$1 data-{$scopedId}",
        $parsed['template'],
        1  // 只替换第一个匹配（根元素）
    );
    
    // 分离import语句和组件定义
    $importStatements = '';
    $componentDefinition = '{}';
    if (preg_match('/^export\s+default\s*(\{.*)$/s', $parsed['script'], $scriptMatches)) {
        $componentDefinition = $scriptMatches[1];
    }else if (preg_match('/^(.*?)(export\s+default\s*\{.*)$/s', $parsed['script'], $scriptMatches)) {
        $importStatements = trim($scriptMatches[1]);
        $componentDefinition = preg_replace('/^export\s+default/', '', $scriptMatches[2]);
    }
    
    // 生成最终JS代码
    $jsCode = <<<JS
{$importStatements}
const exportDefault = {$componentDefinition};
exportDefault.template = `{$scopedTemplate}`;
export default exportDefault;
JS;

// 只有在有样式时才添加样式相关的代码
if (!empty(trim($scopedStyles))) {
    $jsCode = <<<JS
const style = document.createElement('style');
style.textContent = `{$scopedStyles}`;
document.head.appendChild(style);
{$jsCode}
JS;
}
    return $jsCode;
    
    
    
}