<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id
 * @property int $user_id 用户ID
 * @property int $fav_type 收藏类型 1-消息 2-链接 3-文件 4-图文
 * @property array $content 收藏内容
 * @property string $create_time 创建时间
 *
 * @property Users $user
 */
class Favorites extends Model
{
    protected $table = 'wz_favorites';
    protected $primaryKey = 'id';
    public $timestamps = false;
    
    // 收藏类型常量
    const TYPE_MESSAGE = 1;
    const TYPE_LINK = 2;
    const TYPE_FILE = 3;
    const TYPE_IMAGE_TEXT = 4;
    
    protected $fillable = [
        'user_id',
        'fav_type',
        'content'
    ];
    
    protected $casts = [
        'fav_type' => 'integer',
        'content' => 'array',
        'create_time' => 'datetime'
    ];
    
    /**
     * 关联用户
     */
    public function user()
    {
        return $this->belongsTo(Users::class, 'user_id');
    }
    
    /**
     * 获取收藏类型名称
     */
    public function getFavTypeNameAttribute()
    {
        $types = [
            self::TYPE_MESSAGE => '消息',
            self::TYPE_LINK => '链接',
            self::TYPE_FILE => '文件',
            self::TYPE_IMAGE_TEXT => '图文'
        ];
        return $types[$this->fav_type] ?? '未知类型';
    }
}