<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id 文件ID
 * @property int $file_type 文件类型 1-图片 2-语音 3-视频 4-文件
 * @property string $file_path 存储路径
 * @property string $file_name 原始文件名
 * @property int $file_size 文件大小（字节）
 * @property int $duration 音视频时长（秒）
 * @property int $uploader_id 上传者ID
 * @property string $upload_time 上传时间
 * @property int $status 状态 0-已删除 1-正常
 */
class Files extends Model
{
    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'wz_files';
    
    /**
     * The primary key associated with the table.
     *
     * @var string
     */
    protected $primaryKey = 'id';
    
    /**
     * Indicates if the model should be timestamped.
     *
     * @var bool
     */
    public $timestamps = false;
    
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'file_type',
        'file_path',
        'file_name',
        'file_size',
        'duration',
        'uploader_id',
        'status'
    ];
    
    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'file_type' => 'integer',
        'file_size' => 'integer',
        'duration' => 'integer',
        'uploader_id' => 'integer',
        'status' => 'integer',
        'upload_time' => 'datetime'
    ];
    
    /**
     * 获取文件类型名称
     *
     * @return string
     */
    public function getFileTypeNameAttribute()
    {
        $types = [
            1 => '图片',
            2 => '语音',
            3 => '视频',
            4 => '文件'
        ];
        
        return $types[$this->file_type] ?? '未知类型';
    }
    
    /**
     * 获取文件大小带单位
     *
     * @return string
     */
    public function getFileSizeWithUnitAttribute()
    {
        if ($this->file_size >= 1073741824) {
            return round($this->file_size / 1073741824, 2) . ' GB';
        } elseif ($this->file_size >= 1048576) {
            return round($this->file_size / 1048576, 2) . ' MB';
        } elseif ($this->file_size >= 1024) {
            return round($this->file_size / 1024, 2) . ' KB';
        } else {
            return $this->file_size . ' B';
        }
    }
    
    
    /**
     * 关联上传者
     *
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function uploader()
    {
        return $this->belongsTo(Users::class, 'uploader_id');
    }
}