<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id 关系ID
 * @property int $user_id 用户ID
 * @property int $friend_id 好友ID
 * @property string $remark 好友备注
 * @property int $relation_type 关系类型 0-临时会话 1-正式联系人 2-黑名单
 * @property string $created_at 创建时间
 *
 * @property Users $user
 * @property Users $friend
 */
class Friends extends Model
{
    protected $table = 'wz_friends';
    protected $primaryKey = 'id';
    public $timestamps = false;
    
    // 关系类型常量
    const RELATION_TEMPORARY = 0;
    const RELATION_FRIEND = 1;
    const RELATION_BLOCKED = 2;
    
    protected $fillable = [
        'user_id',
        'friend_id',
        'remark',
        'relation_type',
    ];
    
    protected $casts = [
        'relation_type' => 'integer',
        'created_at' => 'datetime'
    ];
    
    /**
     * 关联用户
     */
    public function user()
    {
        return $this->belongsTo(Users::class, 'user_id');
    }
    
    /**
     * 关联好友
     */
    public function friend()
    {
        return $this->belongsTo(Users::class, 'friend_id');
    }
    
    /**
     * 获取关系类型名称
     */
    public function getRelationTypeNameAttribute()
    {
        $types = [
            self::RELATION_TEMPORARY => '临时会话',
            self::RELATION_FRIEND => '好友',
            self::RELATION_BLOCKED => '黑名单'
        ];
        return $types[$this->relation_type] ?? '未知关系';
    }
}