<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id 成员ID
 * @property int $group_id 群组ID
 * @property int $user_id 用户ID
 * @property int $role 角色 0-普通成员 1-管理员 2-群主
 * @property string $join_time 加入时间
 * @property int $status 状态 0-已退出 1-正常
 *
 * @property Groups $group
 * @property Users $user
 */
class GroupMembers extends Model
{
    protected $table = 'wz_group_members';
    protected $primaryKey = 'id';
    public $timestamps = false;
    
    // 角色常量
    const ROLE_MEMBER = 0;
    const ROLE_ADMIN = 1;
    const ROLE_OWNER = 2;
    
    // 状态常量
    const STATUS_LEFT = 0;
    const STATUS_ACTIVE = 1;
    
    protected $fillable = [
        'group_id',
        'user_id',
        'role',
        'status'
    ];
    
    protected $casts = [
        'role' => 'integer',
        'status' => 'integer',
        'join_time' => 'datetime'
    ];
    
    /**
     * 关联群组
     */
    public function group()
    {
        return $this->belongsTo(Groups::class, 'group_id');
    }
    
    /**
     * 关联用户
     */
    public function user()
    {
        return $this->belongsTo(Users::class, 'user_id');
    }
    
    /**
     * 获取角色名称
     */
    public function getRoleNameAttribute()
    {
        $roles = [
            self::ROLE_MEMBER => '成员',
            self::ROLE_ADMIN => '管理员',
            self::ROLE_OWNER => '群主'
        ];
        return $roles[$this->role] ?? '未知角色';
    }
    
    /**
     * 检查是否是群主
     */
    public function isOwner()
    {
        return $this->role === self::ROLE_OWNER;
    }
}