<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id 群组ID
 * @property string $group_name 群名称
 * @property string $avatar 群头像
 * @property int $member_count 成员数量
 * @property int $creator_id 创建者ID
 * @property string $announcement 群公告
 * @property int $status 状态 0-解散 1-正常
 * @property string $created_at 创建时间
 *
 * @property Users $creator
 * @property \Illuminate\Database\Eloquent\Collection|GroupMembers[] $members
 */
class Groups extends Model
{
    protected $table = 'wz_groups';
    protected $primaryKey = 'id';
    public $timestamps = false;
    
    // 状态常量
    const STATUS_DISBANDED = 0;
    const STATUS_ACTIVE = 1;
    
    protected $fillable = [
        'group_name',
        'avatar',
        'creator_id',
        'announcement',
        'status'
    ];
    
    protected $casts = [
        'member_count' => 'integer',
        'creator_id' => 'integer',
        'status' => 'integer',
        'created_at' => 'datetime'
    ];
    
    /**
     * 关联创建者
     */
    public function creator()
    {
        return $this->belongsTo(Users::class, 'creator_id');
    }
    
    /**
     * 关联群成员
     */
    public function members()
    {
        return $this->hasMany(GroupMembers::class, 'group_id');
    }
    
    
    
    /**
     * 检查用户是否是群成员
     */
    public function isMember($userId)
    {
        return $this->members()->where('user_id', $userId)->exists();
    }
}