<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id 消息ID
 * @property int $session_type 会话类型 0-私聊 1-群聊
 * @property int $sender_id 发送者ID
 * @property int $receiver_id 接收者ID
 * @property int $msg_type 消息类型 1-文本 2-图片 3-语音 4-视频 5-文件 6-链接
 * @property string $content 消息内容
 * @property int $file_size 文件大小
 * @property int $duration 音视频时长
 * @property string $thumbnail 缩略图路径
 * @property int $is_read 是否已读 0-未读 1-已读
 * @property string $sent_time 发送时间
 * @property int $status 状态 0-撤回 1-正常
 * @property array $extra 扩展信息
 * 
 * @property Users $sender
 * @property Users|Groups $receiver
 */
class Messages extends Model
{
    protected $table = 'wz_messages';
    protected $primaryKey = 'id';
    public $timestamps = false;

    // 会话类型常量
    const SESSION_PRIVATE = 0;
    const SESSION_GROUP = 1;

    // 消息类型常量
    const TYPE_TEXT = 1;
    const TYPE_IMAGE = 2;
    const TYPE_VOICE = 3;
    const TYPE_VIDEO = 4;
    const TYPE_FILE = 5;
    const TYPE_LINK = 6;

    // 消息状态常量
    const STATUS_REVOKED = 0;
    const STATUS_NORMAL = 1;

    protected $fillable = [
        'session_type',
        'sender_id',
        'receiver_id',
        'msg_type',
        'content',
        'file_size',
        'duration',
        'thumbnail',
        'is_read',
        'status',
        'extra'
    ];

    protected $casts = [
        'session_type' => 'integer',
        'sender_id' => 'integer',
        'receiver_id' => 'integer',
        'msg_type' => 'integer',
        'file_size' => 'integer',
        'duration' => 'integer',
        'is_read' => 'integer',
        'status' => 'integer',
        'sent_time' => 'datetime',
        'extra' => 'array'
    ];

    /**
     * 关联发送者
     */
    public function sender()
    {
        return $this->belongsTo(Users::class, 'sender_id')
        ->select(['id', 'nickname', 'avatar']); // 只选择必要的字段
    }
    /**
     * 关联接收者
     */
    public function receiver()
    {
        return $this->session_type === self::SESSION_PRIVATE 
            ? $this->belongsTo(Users::class, 'receiver_id')
            : $this->belongsTo(Groups::class, 'receiver_id');
    }

    /**
     * 获取会话类型名称
     */
    public function getSessionTypeNameAttribute()
    {
        return $this->session_type === self::SESSION_PRIVATE ? '私聊' : '群聊';
    }

    /**
     * 获取消息类型名称
     */
    public function getMsgTypeNameAttribute()
    {
        $types = [
            self::TYPE_TEXT => '文本',
            self::TYPE_IMAGE => '图片',
            self::TYPE_VOICE => '语音',
            self::TYPE_VIDEO => '视频',
            self::TYPE_FILE => '文件',
            self::TYPE_LINK => '链接'
        ];
        return $types[$this->msg_type] ?? '未知类型';
    }
    
    public function getAbstractAttribute(){
        if($this->msg_type == self::TYPE_TEXT){
            return $this->content;
        }
        return $this->msg_type_name;
    }
    
}