<?php

namespace plugin\wz_chat\app\model;
use support\Model;

/**
 * @property int $id ID 关联 wa_user id
 * @property string $nickname 昵称
 * @property string $avatar 头像URL
 * @property int $verify 验证状态 1-没验证 2-需要验证
 * @property string $sign 签名说明
 * @property string $created_at 创建时间
 * @property int online 是否在线
 * @method static \Illuminate\Database\Query\Builder|Users whereId($value)
 * @method static \Illuminate\Database\Query\Builder|Users whereNickname($value)
 * @method static \Illuminate\Database\Query\Builder|Users whereAvatar($value)
 * @method static \Illuminate\Database\Query\Builder|Users whereVerify($value)
 * @method static \Illuminate\Database\Query\Builder|Users whereSign($value)
 * @method static \Illuminate\Database\Query\Builder|Users whereCreatedAt($value)
 */
class Users extends Model
{
    protected $table = 'wz_users';
    protected $primaryKey = 'id';
    public $timestamps = false;

    protected $fillable = [
        'nickname',
        'avatar',
        'verify',
        'sign'
    ];

    protected $casts = [
        'verify' => 'integer',
        'online' => 'boolean', 
        'created_at' => 'datetime'
    ];

    

    /**
     * 用户的好友关系
     */
    public function friends()
    {
        return $this->hasMany(Friends::class, 'user_id')->where('relation_type','1');
    }
    /**
    * 检查用户是否在线
    */
    public function isOnline()
    {
        return (bool)$this->online;
    }

    /**
     * 用户加入的群组
     */
    public function groups()
    {
        return $this->belongsToMany(Groups::class, 'wz_group_members', 'user_id', 'group_id');
    }
}