// store/modules/chats.js

const chatsModule = {
	namespaced: true,
	state: () => ({
    chats: SessionStorage.getSessions().map(session => ({
      id: session.id,
      name: session.name,
      avatar: session.avatar,
      lastMsg: session.lastMsg,
      lastId: session.lastId,
      time: session.time,
      group: session.group,
      unread: session.unread,
      members: session.members,
      messages: [],
      is_friend: session.is_friend
    })),
    currentChatId: null,
    currentChat: null
  }),
  mutations: {
    SET_CHATS(state, chats) {
      state.chats = chats;
      SessionStorage.saveSessions(chats);
    },
    SET_CURRENT_CHAT_ID(state, chatId) {
      state.currentChatId = chatId
      state.currentChat = state.chats.find(chat => chat.id === chatId)
    },
    SET_CURRENT_CHAT(state, chat) {
    	if(chat){
    		state.currentChatId = chat.id;
            state.currentChat = chat;
    	}else{
    		state.currentChatId = null;
            state.currentChat = null;
    	}
        
    },
   
      
    ADD_CHAT(state, chat) {
      const index = state.chats.findIndex(c => c.id == chat.id && c.group == chat.group )
      if (index === -1) {
        state.chats.push(chat)
      } else {
        state.chats.splice(index, 1, chat)
      }
      SessionStorage.saveSessions(state.chats);
    },
    UPDATE_CHAT(state, { id, group,updates }) {
      const chat = state.chats.find(c => c.id === id && c.group == group)
      if (chat) {
        Object.assign(chat, updates)
      }
    },
    
    MARK_CHAT_AS_READ(state, chatId) {
      const chat = state.chats.find(c => c.id === chatId)
      if (chat) {
        chat.unread = 0
      }
      SessionStorage.saveSessions(state.chats);
    }
  },
  actions: {
	  
	  addMessage({ rootState, state }, {chat, message }) {
	      if(message.sender && message.sender.id == rootState.user.id){ 
			 message.type = 'sent';
			 message.sender = null;
		  }
	      const findChat = state.chats.find(c => c.id === chat.id && c.group==chat.group )
	      if (findChat) {
	    	findChat.messages.push(message)
	        findChat.lastMsg = message.content
	        findChat.lastId = message.id
	        findChat.time = message.time       
	        if (findChat!= state.currentChat) { 
	        	findChat.unread = (chat.unread || 0) + 1
	        }else{
	        	findChat.unread = 0;
	        }
	    	if(findChat == state.currentChat){
	    		Event.trigger('scrollToBottom');
	    	}
	      }else{
	    	  chat.messages=[message];
	    	  state.chats.push(chat);
	    	  if(chat == state.currentChat){
	    		  Event.trigger('scrollToBottom');
		      }
	      }
	  }, 
	  tempChat({rootState, state,commit},user){
		  const uid = user.id;
		  let chat = state.chats.find(c => c.id === uid && !c.group);
	    
		  if (chat) {
			  commit('SET_CURRENT_CHAT', chat);
			  return;
		  }

		const friend = rootState.friends.friends.find(u => u.id === uid);
		chat = {
		  id: uid,
		  name: friend ? friend.display_name : user.nickname,
		  avatar: friend ? friend.avatar : user.avatar,
		  lastMsg: '',
		  lastId: 0,
		  time: Date.now(),
		  group: false,
		  unread: 0,
		  members: 1,
		  messages: [],
		  is_friend: !!friend
		};
		
		commit('ADD_CHAT', chat);
		commit('SET_CURRENT_CHAT', chat);
	  },
	  fetchChatMessages({ commit, state },chat) {
		  
		  var mid = chat.messages.length?chat.messages[0].id:-1;
	      return fetchGet('message-historys',{
	    	  id:chat.id,
	    	  group:chat.group?'1':'0',
	    	 mid:mid}
	      ).then(json=>{      
    		if(json.data && json.data.length){
    			let list = json.data;
    			for(var i=0;i<chat.messages.length;i++){
    				list.push(chat.messages[i]);
    			}
    			chat.messages = list; 
    			Event.trigger('scrollToBottom');
    		}
	      });
     },
    fetchUnreadMessages({ commit, state }) {
      const lastIds = {}
      state.chats.forEach(chat => {
        if (chat.group) {
          lastIds.groups = lastIds.groups || {}
          lastIds.groups[chat.id] = chat.lastId || 0
        } else {
          lastIds.friends = lastIds.friends || {}
          lastIds.friends[chat.id] = chat.lastId || 0
        }
      })
      
      return fetchPost('get-unread', lastIds).then(json => {
        if (json.data) {
          json.data.existing.forEach(item => {
            commit('UPDATE_CHAT', {
              id: item.id,
              updates: {
                unread: item.unread,
                lastId: item.lastId,
                ...(!item.group && { is_friend: item.is_friend })
              }
            })
          })
          
          json.data.new_chats.forEach(newChat => {
            commit('ADD_CHAT', {
              ...newChat,
              messages: []
            })
          })
        }
      })
    }
  },
  getters: {
    allChats: state => state.chats,
    currentChat: state => state.currentChat,
    unreadCount: state => state.chats.reduce((sum, chat) => sum + (chat.unread || 0), 0)
  }
}

export default chatsModule