// store/modules/friends.js
const friendsModule = {
	namespaced: true,
	state: () => ({
    friends: [],
    favorites: [
      {
        id: 'f1',
        title: '项目文档',
        desc: '说什么咩咩咩咩',
        time: Date.now() - 1209600000 // 14天前
      }
    ]
  }),
  mutations: {
    SET_FRIENDS(state, friends) {
      state.friends = friends
    },
    UPDATE_FRIEND(state, { id, updates }) {
      const friend = state.friends.find(f => f.id === id)
      if (friend) {
        Object.assign(friend, updates)
      }
    },
    ADD_FRIEND(state, friend) {
      const index = state.friends.findIndex(f => f.id === friend.id)
      if (index === -1) {
        state.friends.push(friend)
      } else {
        state.friends.splice(index, 1, friend)
      }
    },
    REMOVE_FRIEND(state, friendId) {
      state.friends = state.friends.filter(f => f.id !== friendId)
    }
  },
  actions: {
    fetchFriends({ commit }) {
      return fetchGet('friends').then(json => {
        if (!json.code) {
          commit('SET_FRIENDS', json.data)
        }
      })
    },
    updateFriendOnlineStatus({ commit }, { userId, online }) {
      commit('UPDATE_FRIEND', {
        id: userId,
        updates: { online }
      })
    },
    editFriendRemark({ commit }, { fid, remark }) {
      return fetchPost('editfriendRemark', { fid, remark }).then(json => {
        if (json.code === 0) {
          commit('UPDATE_FRIEND', {
            id: fid,
            updates: { remark }
          })
        }
        return json
      })
    }
  },
  getters: {
    allFriends: state => state.friends,
    onlineFriends: state => state.friends.filter(f => f.online),
    offlineFriends: state => state.friends.filter(f => !f.online),
    friendById: state => id => state.friends.find(f => f.id === id),
    favorites: state => state.favorites
  }
}

export default friendsModule