// store/modules/groups.js
const groupsModule = {
	namespaced: true,
	state: () => ({
    groups: [],
    onlineCountInterval: null
  }),
  mutations: {
    SET_GROUPS(state, groups) {
      state.groups = groups
    },
    ADD_GROUP(state, group) {
      const index = state.groups.findIndex(g => g.id === group.id)
      if (index === -1) {
        state.groups.push(group)
      } else {
        state.groups.splice(index, 1, group)
      }
    },
    UPDATE_GROUP(state, { id, updates }) {
      const group = state.groups.find(g => g.id === id)
      if (group) {
        Object.assign(group, updates)
      }
    },
    REMOVE_GROUP(state, groupId) {
      state.groups = state.groups.filter(g => g.id !== groupId)
    },
    SET_ONLINE_COUNTS(state, counts) {
      state.groups = state.groups.map(group => {
        const newCount = counts[group.id]
        if (typeof newCount !== 'undefined') {
          return {
            ...group,
            online_count: parseInt(newCount) || 0
          }
        }
        return group
      })
    }
  },
  actions: {
    fetchGroups({ commit, dispatch }) {
      return fetchGet('groups').then(json => {
        if (!json.code) {
          commit('SET_GROUPS', json.data)
          dispatch('startOnlineCountUpdates')
        }
      })
    },
    startOnlineCountUpdates({ commit, state }) {
      if (state.onlineCountInterval) {
        clearInterval(state.onlineCountInterval)
      }
      
      const update = () => {
        if (!state.groups.length) return
        const groupIds = state.groups.map(g => g.group_id || g.id)
        fetchGet('group-onlines', { ids: groupIds.join(',') }).then(json => {
          if (json.code === 0) {
            commit('SET_ONLINE_COUNTS', json.data)
          }
        })
      }
      
      update() // 立即执行一次
      state.onlineCountInterval = setInterval(update, 15000)
    },
    createGroup({ commit }, { name, members }) {
      return fetchPost('create-group', { name, members }).then(json => {
        if (json.code === 0) {
          commit('ADD_GROUP', json.data.group)
          commit('chats/ADD_CHAT', {
            id: json.data.group.id,
            name: json.data.group.group_name,
            avatar: json.data.group.avatar,
            lastMsg: json.data.message.content,
            lastId: json.data.message.id,
            time: json.data.message.time,
            group: true,
            unread: 1,
            members: json.data.group.member_count,
            messages: [json.data.message]
          }, { root: true })
        }
        return json
      })
    }
  },
  getters: {
    allGroups: state => state.groups,
    groupById: state => id => state.groups.find(g => g.id === id)
  }
}

export default groupsModule