// store/modules/requests.js
const requestsModule = {
	namespaced: true,
	state: () => ({
    receivedRequests: [],
    sentRequests: []
  }),
  mutations: {
    SET_REQUESTS(state, { received, sent }) {
      state.receivedRequests = received
      state.sentRequests = sent
    },
    ADD_RECEIVED_REQUEST(state, request) {
      const index = state.receivedRequests.findIndex(r => r.id === request.id)
      if (index === -1) {
        state.receivedRequests.unshift(request)
      } else {
        state.receivedRequests.splice(index, 1, request)
      }
    },
    ADD_SENT_REQUEST(state, request) {
      const index = state.sentRequests.findIndex(r => r.id === request.id)
      if (index === -1) {
        state.sentRequests.unshift(request)
      } else {
        state.sentRequests.splice(index, 1, request)
      }
    },
    UPDATE_REQUEST_STATUS(state, { id, status, type }) {
      const requests = type === 'received' ? state.receivedRequests : state.sentRequests
      const request = requests.find(r => r.id === id)
      if (request) {
        request.status = status
      }
    }
  },
  actions: {
    fetchRequests({ commit }) {
      return fetchGet('requests').then(json => {
        if (!json.code) {
          commit('SET_REQUESTS', json.data)
        }
      })
    },
    sendFriendRequest({ commit }, { receiverId, message }) {
      return fetchPost('requestFriend', { receiver_id: receiverId, message }).then(json => {
        if (json.code === 0 && json.data && json.data.sent) {
          commit('ADD_SENT_REQUEST', json.data.sent)
        }
        return json
      })
    },
    acceptFriendRequest({ commit, dispatch }, requestId) {
      return fetchPost('requestAccept', { id: requestId }).then(json => {
        if (json.code === 0) {
          commit('UPDATE_REQUEST_STATUS', { id: requestId, status: 'accepted', type: 'received' })
          dispatch('friends/fetchFriends', null, { root: true })
        }
        return json
      })
    },
    rejectFriendRequest({ commit }, requestId) {
      return fetchPost('requestReject', { id: requestId }).then(json => {
        if (json.code === 0) {
          commit('UPDATE_REQUEST_STATUS', { id: requestId, status: 'rejected', type: 'received' })
        }
        return json
      })
    }
  },
  getters: {
    receivedRequests: state => state.receivedRequests,
    sentRequests: state => state.sentRequests,
    pendingReceivedRequests: state => state.receivedRequests.filter(r => r.status === 'pending'),
    pendingSentRequests: state => state.sentRequests.filter(r => r.status === 'pending')
  }
}

export default requestsModule