-- 收藏表
CREATE TABLE `wz_favorites` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) UNSIGNED NOT NULL,
  `fav_type` tinyint(4) NOT NULL COMMENT '1-消息 2-链接 3-文件 4-图文',
  `content` text NOT NULL COMMENT '收藏内容（JSON格式）',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `idx_user_type` (`user_id`,`fav_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='收藏表';

-- 文件存储表
CREATE TABLE `wz_files` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,
  `file_type` tinyint(4) NOT NULL COMMENT '1-图片 2-语音 3-视频 4-文件',
  `file_path` varchar(255) NOT NULL COMMENT '存储路径',
  `file_name` varchar(255) NOT NULL COMMENT '原始文件名',
  `file_size` int(10) UNSIGNED NOT NULL COMMENT '文件大小（字节）',
  `duration` int(10) UNSIGNED DEFAULT '0' COMMENT '音视频时长（秒）',
  `uploader_id` bigint(20) UNSIGNED NOT NULL COMMENT '上传者ID',
  `upload_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `status` tinyint(4) NOT NULL DEFAULT '1' COMMENT '0-已删除 1-正常',
  PRIMARY KEY (`id`),
  KEY `idx_uploader` (`uploader_id`,`upload_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='文件存储表';

-- 好友关系表
CREATE TABLE `wz_friends` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '关系ID',
  `user_id` bigint(20) UNSIGNED NOT NULL COMMENT '用户ID',
  `friend_id` bigint(20) UNSIGNED NOT NULL COMMENT '好友ID',
  `remark` varchar(50) NOT NULL DEFAULT '' COMMENT '好友备注',
  `relation_type` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-临时会话 1-正式联系人 2黑名单',
  `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `idx_user_friend` (`user_id`,`friend_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='好友关系表';

-- 好友申请表
CREATE TABLE `wz_friend_requests` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '请求ID',
  `requester_id` varchar(20) NOT NULL COMMENT '申请者用户ID',
  `receiver_id` varchar(20) NOT NULL COMMENT '接收者用户ID',
  `message` varchar(255) DEFAULT NULL COMMENT '申请留言',
  `status` enum('pending','accepted','rejected','cancelled') NOT NULL DEFAULT 'pending' COMMENT '申请状态',
  `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `idx_requester` (`requester_id`),
  KEY `idx_receiver` (`receiver_id`),
  KEY `idx_status` (`status`),
  KEY `idx_created` (`created_at`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='好友申请表';

-- 群组表
CREATE TABLE `wz_groups` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '群组ID',
  `group_name` varchar(50) NOT NULL COMMENT '群名称',
  `avatar` varchar(255) NOT NULL DEFAULT '' COMMENT '群头像',
  `member_count` int(10) UNSIGNED NOT NULL DEFAULT '0' COMMENT '成员数量',
  `creator_id` bigint(20) UNSIGNED NOT NULL COMMENT '创建者ID',
  `announcement` text COMMENT '群公告',
  `status` tinyint(4) NOT NULL DEFAULT '1' COMMENT '状态 0-解散 1-正常',
  `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `idx_creator` (`creator_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='群组表';

-- 群组成员表
CREATE TABLE `wz_group_members` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '成员ID',
  `group_id` bigint(20) UNSIGNED NOT NULL COMMENT '群组ID',
  `user_id` bigint(20) UNSIGNED NOT NULL COMMENT '用户ID',
  `role` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-普通成员 1-管理员 2-群主',
  `join_time` datetime NOT NULL COMMENT '加入时间',
  `status` tinyint(4) NOT NULL DEFAULT '1' COMMENT '0-已退出 1-正常',
  PRIMARY KEY (`id`),
  UNIQUE KEY `idx_group_user` (`group_id`,`user_id`),
  KEY `idx_user_status` (`user_id`,`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='群组成员表';

-- 消息表
CREATE TABLE `wz_messages` (
  `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '消息ID',
  `session_type` tinyint(4) DEFAULT NULL COMMENT '0-私聊 1-群聊',
  `sender_id` int(11) DEFAULT NULL COMMENT '发送者ID',
  `receiver_id` int(11) DEFAULT NULL COMMENT '接收者ID（用户或群组）',
  `msg_type` tinyint(4) DEFAULT NULL COMMENT '消息类型 1-文本 2-图片 3-语音 4-视频 5-文件 6-链接',
  `content` text COMMENT '消息内容（文本内容/文件路径/链接等）',
  `file_size` int(10) UNSIGNED DEFAULT '0' COMMENT '文件大小（字节）',
  `duration` int(11) DEFAULT '0' COMMENT '音视频时长（秒）',
  `thumbnail` varchar(255) DEFAULT NULL COMMENT '缩略图路径',
  `is_read` tinyint(4) DEFAULT '0' COMMENT '是否已读 0-未读 1-已读',
  `sent_time` datetime DEFAULT NULL COMMENT '发送时间',
  `status` tinyint(4) DEFAULT '1' COMMENT '状态 0-撤回 1-正常',
  `extra` text COMMENT '扩展信息',
  PRIMARY KEY (`id`),
  KEY `idx_time` (`sent_time`),
  KEY `idx_session` (`session_type`),
  KEY `idx_sender_id` (`sender_id`),
  KEY `idx_receiver_id` (`receiver_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='消息表';

-- 聊天用户表
CREATE TABLE `wz_users` (
  `id` bigint(20) UNSIGNED NOT NULL COMMENT 'ID 关联 wa_user id',
  `nickname` varchar(50) NOT NULL DEFAULT '' COMMENT '昵称',
  `avatar` varchar(255) NOT NULL DEFAULT '' COMMENT '头像URL',
  `verify` tinyint(4) NOT NULL DEFAULT '1' COMMENT '申请 1-没验证 2-需要验证',
  `sign` varchar(50) NOT NULL DEFAULT '' COMMENT '签名说明',
  `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `online` tinyint(4) DEFAULT '0' COMMENT '是否在线',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='聊天用户表';